@@ -1,20 +1,16 @@
-package Tkx::TclTk::Bind;
-
 # ##############################################################################
 # # Script     : Tkx::TclTk::Bind.pm                                           #
 # # -------------------------------------------------------------------------- #
 # # Copyright  : Frei unter GNU General Public License  bzw.  Artistic License #
-# # Autoren    : Jrgen von Brietzke                                   JvBSoft #
-# # Version    : 1.2.01                                            16.Jun.2013 #
+# # Authors    : JVBSOFT - Jrgen von Brietzke                   0.001 - 1.300 #
+# # Version    : 1.300                                             19.Dez.2015 #
 # # -------------------------------------------------------------------------- #
-# # Aufgabe    : Bindet TclTk-Bibliotheken an Perl::Tkx                        #
+# # Function   : Bindet TclTk-Bibliotheken an Perl::Tkx                        #
 # # -------------------------------------------------------------------------- #
-# # Sprache    : PERL 5                                (V)  5.8.xx  -  5.16.xx #
-# # Kodierung  : ISO 8859-15 / Latin-9                         UNIX-Zeilenende #
+# # Language   : PERL 5                                (V) 5.12.xx  -  5.22.xx #
+# # Coding     : ISO 8859-15 / Latin-9                         UNIX-Zeilenende #
 # # Standards  : Perl-Best-Practices                       severity 1 (brutal) #
 # # -------------------------------------------------------------------------- #
-# # Pragmas    : base, strict, version, warnings                               #
-# # -------------------------------------------------------------------------- #
 # # Module     : Archive::Tar                           ActivePerl-CORE-Module #
 # #              Config                                                        #
 # #              English                                                       #
@@ -22,17 +18,14 @@ package Tkx::TclTk::Bind;
 # #              File::Spec                                                    #
 # #              Tkx                                                           #
 # #              ------------------------------------------------------------- #
-# #              Const::Fast                                       CPAN-Module #
+# #              Const::Fast                            ActivePerl-REPO-Module #
 # #              File::Remove                                                  #
-# # -------------------------------------------------------------------------- #
-# # TODO       : POD - Documentation                                           #
+# #              Perl::Modern::Perl                                            #
 # ##############################################################################
 
-use strict;
-use warnings;
+package Tkx::TclTk::Bind 1.300;
 
-use version;
-our $VERSION = q{1.2.01};
+# ##############################################################################
 
 use Archive::Tar;
 use Config;
@@ -40,6 +33,7 @@ use Const::Fast;
 use English qw{-no_match_vars};
 use File::Remove qw{remove};
 use File::Spec;
+use Perl::Modern::Perl qw{5.12};
 use Tkx;
 
 # ##############################################################################
@@ -89,9 +83,10 @@ sub load_library {
       = defined $ENV{TMP}    ? $ENV{TMP}
       : defined $ENV{TEMP}   ? $ENV{TEMP}
       : defined $ENV{TMPDIR} ? $ENV{TMPDIR}
+      : defined $ENV{HOME}   ? $ENV{HOME}
       :                        undef;
    if ( not defined $TEMP_DIR ) {
-      _error( 'No environment value "ENV{TMP & TEMP & TMPDIR}" found',
+      _error( 'No environment value "ENV{TMP & TEMP & TMPDIR & HOME}" found',
          $library );
    }
 
@@ -126,6 +121,7 @@ sub load_library {
    my $archiv;
 
    # --- Archiv-Datei aus 'PerlApp' laden --------------------------------------
+   no warnings;
    if ( defined $PerlApp::BUILD ) {
       $archiv = PerlApp::extract_bound_file($tar_name);
       if ( not defined $archiv ) {
@@ -145,6 +141,7 @@ sub load_library {
          _error( "Library '$tar_name' not found", $library );
       }
    }
+   use warnings;
 
    # --- Archiv-Datei in TEMP-Verzeichnis entpacken ----------------------------
    my $tar = Archive::Tar->new();
@@ -204,15 +201,15 @@ sub _error {
 
 __END__
 
-=pod
-
 =head1 NAME
 
 Tkx::TclTk::Bind - Load Tcl/Tk-Library to Temp-Directory
 
+
 =head1 VERSION
 
-This is version 1.2.01
+This document describes Perl::Modern::Perl version 1.300.
+
 
 =head1 SYNOPSIS
 
@@ -220,9 +217,10 @@ This is version 1.2.01
    ...
    my $temp_dir = load_library('tlc-tk-library-archiv');
 
+
 =head1 DESCRIPTION
 
-This modul is a helper-modul for moduls:
+The module is an auxiliary module for:
 
 =over 3
 
@@ -234,62 +232,136 @@ This modul is a helper-modul for moduls:
 
 Use this modul not direct !!!
 
-=head1 FUNCTIONS
+
+=head1 DIAGNOSTICS
+
+All error messages are displayed in a Tkx MessageBox.
+
+=head2 No environment value "ENV{TMP & TEMP & TMPDIR & HOME}" found
+
+Could not find environment variable to store the libraries.
+
+=head2 Can't create directory\nTEMP_DIR
+
+Can not display the directory for the libraries.
+
+=head2 System xxxxxx is not supported
+
+The current operating system is not supported.
+
+=head2 System type unknown - must be 32- or 64-bit
+
+t can not be determined whether the Perl version is based on 32 or 64 bits.
+
+=head2 Library 'xxxxxx' not boundet
+
+The library was not involved in the production of B<PerlApp>.
+
+=head2 Library 'xxxxxx' not found
+
+The library was not found.
+
+=head2 Can't create directory\n$xxxxxx
+
+The temporary working directory can not be created.
+
+=head2 Can't open\nxxxxxx  /  Can't print\nxxxxxx  /  Can't close\nxxxxxx
+
+The library can not be exported or saved.
+
+
+=head1 INTERFACE
 
 =head2 load_library(...)
 
 Load and extract the given library-archiv (TAR-Ball without system-type and
 '.tar') to the User-TEMP-Directory.
 
-When program will ending, the modul delete all temp-files.
+When you exit the program, the libraries are unloaded.
 
 The modul include support for B<PerlApp> from B<ActiveState>.
 
-=head1 PRAGMAS
 
-=over 3
+=head1 CONFIGURATION AND ENVIRONMENT
 
-=item base
+The binding to libraries in a directory under the environment variable:
 
-=item strict
+   - TMP
+   - TEMP
+   - TEMPDIR
+   - HOME
 
-=item version
+stored. The search sequence corresponds to the sequence shown.
 
-=item warnings
 
-=back
+=head1 DEPENDENCIES
 
-=head1 MODULE
+The following pragmas and modules are required:
 
-=over 3
+=head2 CORE
 
-=item Archive::Tar
+   - Archive::Tar
+   - Config
+   - English
+   - Exporter
+   - File::Spec
+   - Tkx
 
-=item Config
+=head2 CPAN or ActiveState Repository
 
-=item Const::Fast
+   - Const::Fast
+   - File::Remove
+   - Perl::Modern::Perl
 
-=item English
 
-=item Exporter
+=head1 INCOMPATIBILITIES
 
-=item File::Remove
+The module works with PERL 5:12 or higher under MS Win, Linux and Max OS.
 
-=item File::Spec
 
-=item Tkx
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests to
+C<bug-perl-modern-moose@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.
 
-=back
 
 =head1 AUTHOR
 
-Juergen von Brietzke <juergen.von.brietzke@t-online.de>
+Juergen von Brietzke  C<< <juergen.von.brietzke@t-online.de> >>
 
-=head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) by Juergen von Brietzke.
+=head1 LICENCE AND COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Copyright (c) 2015,
+Juergen von Brietzke C<< <juergen.von.brietzke@t-online.de> >>.
+All rights reserved.
 
-=cut
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
